==> haskell-hspec-contrib-0.5.2-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-contrib
version:              0.5.2
visibility:           public
id:                   hspec-contrib-0.5.2-LKzuVOm7EvkGIIXA9EWrI9
key:                  hspec-contrib-0.5.2-LKzuVOm7EvkGIIXA9EWrI9
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  78dfe57527caf16cd541a72c121b21a6
exposed:              True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Mocks.V1
    Test.Hspec.Contrib.Retry

hidden-modules:       Paths_hspec_contrib
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-contrib
hs-libraries:         HShspec-contrib-0.5.2-LKzuVOm7EvkGIIXA9EWrI9
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hspec-core-2.11.3-AIpyqTc1kue3JLLorF2nbi

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.2-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-contrib
version:              0.5.2
visibility:           public
id:                   hspec-contrib-0.5.2-6VKItGfLQZn1EQvF9IyQMz
key:                  hspec-contrib-0.5.2-6VKItGfLQZn1EQvF9IyQMz
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  4cd9cbe70959f146efcbde15be014262
exposed:              True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Mocks.V1
    Test.Hspec.Contrib.Retry

hidden-modules:       Paths_hspec_contrib
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-contrib
hs-libraries:         HShspec-contrib-0.5.2-6VKItGfLQZn1EQvF9IyQMz
depends:
    HUnit-1.6.2.0-LMZJFH0qO0O4E6bB1AMjU3 base-4.17.2.1
    call-stack-0.4.0-nZYudfotnA5XHHO6D4mRj
    hspec-core-2.11.3-AJUV3eYoh6bD6Fh6jWbr6D

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
